clear
set mem 100M
version 10.0
cd "d:\investigacion\paper on parity\data"
capture log close
log using "log parity 7-9-2009", replace

********************************************************************************************************************************
****Table 1: Available Exams and Committees, by Type of Examination*************************************************************
********************************************************************************************************************************

clear
use committees
bys corps year: egen number_of_committees=max(committee)
collapse (mean) number_of_committees written binding, by(corps year) 

**ROW (1) 
tab corps

**ROW (2)
tab written corps

**ROW (3)
tab binding corps

**ROW (4)
bys corps: sum number_of_committees

**ROW (5)
clear
use committees
tab corps


********************************************************************************************************************************
****Table 2: Descriptive Statistics - Characteristics of Successful Candidates at the Individual Level, by Type of Examination**
********************************************************************************************************************************
clear
use "successful candidates.dta", clear
bys corps: sum female normalized_grade

*****************************************************TABLE 3*******************************************************************
****Table 3: Descriptive Statistics - Committee Level**************************************************************************
*******************************************************************************************************************************

clear
use committees

**ROWS (1)-(5)
sum available_positions successful_candidates female_successful_candidates male_successful_candidates share_successful_female

**ROWS (6)-(16)
xi: sum members_committee gender_committee i.non_linearities age_committee experience_committee ranking_committee 

*******************************************************************************************************************************
****Table 4: Descriptive Statistics - Candidates to Judge and Prosecutor (2003-2007) and Court Secretary (2006) Positions******
*******************************************************************************************************************************

use "candidates.dta", clear

**COLUMN (1)
sum took_exam passed1 passed2 passed3 win
tab experience_candidate

**COLUMNS (2)&(3)
bys female: sum took_exam passed1 passed2 passed3 win
bys female: tab experience_candidate


*****************************************************************************************************************************
*****Table 5: Gender Composition of Committee and Probability of Success*****************************************************
*****************************************************************************************************************************

clear
use "committees.dta"
capture xtreg ln_female_successful_candidates gender_committee ln_available_positions, fe i(corps_year) cluster(corps_year)
est store a
capture xi: xtreg ln_female_successful_candidates i.non_linearities ln_available_positions, fe i(corps_year) cluster(corps_year)
est store b
capture xtreg ln_male_successful_candidates gender_committee  ln_available_positions, fe i(corps_year) cluster(corps_year)
est store c
capture xi: xtreg ln_male_successful_candidates i.non_linearities ln_available_positions, fe i(corps_year) cluster(corps_year)
est store d
capture xtreg ln_share_successful_female gender_committee ln_available_positions, fe i(corps_year) cluster(corps_year) 
est store e
capture xi: xtreg ln_share_successful_female i.non_linearities ln_available_positions, fe i(corps_year) cluster(corps_year)
est store f
capture xtreg ln_successful_candidates gender_committee ln_available_positions, fe i(corps_year) cluster(corps_year)
est store g
capture xi: xtreg ln_successful_candidates i.non_linearities ln_available_positions, fe i(corps_year) cluster(corps_year)
est store h

estout a b c d e f g h,/*
*/ drop(_cons) order(gender_committee _Inon_linea_1 _Inon_linea_2 _Inon_linea_3 _Inon_linea_4 _Inon_linea_5 ln_available_positions) /*
*/ cells(b(star fmt(%9.2f)) se(par fmt(%9.2f))) stats(r2_a N,  fmt(%9.3f %9.0f)/*
*/ labels("Adjusted R-sq" N)) legend label collabels(, none) /*
*/ varlabels(gender_committee Female_share) posthead("") prefoot("") postfoot("") /*
*/ varwidth(20) modelwidth(7) delimiter("") style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) 

*****************************************************************************************************************************
*****Table 6: Gender Composition of Committee and Probability of Success, by Decade and Type of Examination******************
*****************************************************************************************************************************

**PANEL (1)**

capture xi: xtreg ln_female_successful_candidates minority majority ln_available_positions, fe i(corps_year) cluster(corps_year)
est store a
capture xi: xtreg ln_male_successful_candidates minority majority ln_available_positions, fe i(corps_year) cluster(corps_year)
est store b
capture xi: xtreg ln_share_successful_female minority majority ln_available_positions, fe i(corps_year) cluster(corps_year)
est store c
capture xi: xtreg ln_successful_candidates minority majority ln_available_positions, fe i(corps_year) cluster(corps_year)
est store d
estout a b c d ,/*
*/ drop(ln_available_positions _cons) /*
*/ cells(b(star fmt(%9.2f)) se(par fmt(%9.2f))) stats(r2_a N,  fmt(%9.3f %9.0f)/*
*/ labels("Adjusted R-sq" N)) legend label collabels(, none) /*
*/ varlabels(gender_committee Female_share) posthead("") prefoot("") postfoot("") /*
*/ varwidth(20) modelwidth(7) delimiter("") style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) 

**PANEL (2)**
capture xi: xtreg ln_female_successful_candidates minority majority ln_available_positions if year<1997, fe i(corps_year) cluster(corps_year)
est store a
capture xi: xtreg ln_male_successful_candidates minority majority ln_available_positions if year<1997, fe i(corps_year) cluster(corps_year)
est store b
capture xi: xtreg ln_share_successful_female minority majority ln_available_positions if year<1997, fe i(corps_year) cluster(corps_year)
est store c
capture xi: xtreg ln_successful_candidates minority majority ln_available_positions if year<1997, fe i(corps_year) cluster(corps_year)
est store d
estout a b c d ,/*
*/ drop(ln_available_positions _cons) /*
*/ cells(b(star fmt(%9.2f)) se(par fmt(%9.2f))) stats(N, fmt(%9.0f)/*
*/ labels(N)) legend label collabels(, none) /*
*/ varlabels(gender_committee Female_share) posthead("") prefoot("") postfoot("") /*
*/ varwidth(20) modelwidth(7) delimiter("") style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) 

**PANEL (3)**

capture xi: xtreg ln_female_successful_candidates minority majority ln_available_positions if year>=1997, fe i(corps_year) cluster(corps_year)
est store a
capture xi: xtreg ln_male_successful_candidates minority majority ln_available_positions if year>=1997, fe i(corps_year) cluster(corps_year)
est store b
capture xi: xtreg ln_share_successful_female minority majority ln_available_positions if year>=1997, fe i(corps_year) cluster(corps_year)
est store c
capture xi: xtreg ln_successful_candidates minority majority ln_available_positions if year>=1997, fe i(corps_year) cluster(corps_year)
est store d
estout a b c d ,/*
*/ drop(ln_available_positions _cons) /*
*/ cells(b(star fmt(%9.2f)) se(par fmt(%9.2f))) stats(N, fmt(%9.0f)/*
*/ labels(N)) legend label collabels(, none) /*
*/ varlabels(gender_committee Female_share) posthead("") prefoot("") postfoot("") /*
*/ varwidth(20) modelwidth(7) delimiter("") style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) 

**PANELS (4)-(8)**
foreach i in S J JyF N F {
capture xi: xtreg ln_female_successful_candidates minority majority ln_available_positions if corps=="`i'", fe i(corps_year) cluster(corps_year)
est store a
capture xi: xtreg ln_male_successful_candidates minority majority ln_available_positions if corps=="`i'", fe i(corps_year) cluster(corps_year)
est store b
capture xi: xtreg ln_share_successful_female minority majority ln_available_positions if corps=="`i'", fe i(corps_year) cluster(corps_year)
est store c
capture xi: xtreg ln_successful_candidates minority majority ln_available_positions if corps=="`i'", fe i(corps_year) cluster(corps_year)
est store d
estout a b c d ,/*
*/ drop(ln_available_positions _cons) /*
*/ cells(b(star fmt(%9.2f)) se(par fmt(%9.2f))) stats(N, fmt(%9.0f)/*
*/ labels(N)) legend label collabels(, none) /*
*/ varlabels(gender_committee Female_share) posthead("") prefoot("") postfoot("") /*
*/ varwidth(20) modelwidth(7) delimiter("") style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) 
}

*****************************************************************************************************************************
*****Table 7: Committee Characteristics and Probability of Success***********************************************************
*****************************************************************************************************************************

capture xi: xtreg ln_female_successful_candidates minority majority age_committee experience_committee ranking_committee ln_available_positions, fe i(corps_year) cluster(corps_year)
est store a
capture xi: xtreg ln_male_successful_candidates minority majority age_committee experience_committee ranking_committee ln_available_positions, fe i(corps_year) cluster(corps_year)
est store b
capture xi: xtreg ln_share_successful_female minority majority age_committee experience_committee ranking_committee ln_available_positions, fe i(corps_year) cluster(corps_year)
est store c
capture xi: xtreg ln_successful_candidates minority majority age_committee experience_committee ranking_committee ln_available_positions, fe i(corps_year) cluster(corps_year)
est store d
estout a b c d ,/*
*/ drop(_cons) /*
*/ cells(b(star fmt(%9.2f)) se(par fmt(%9.2f))) stats(N, fmt(%9.0f)/*
*/ labels(N)) legend label collabels(, none) /*
*/ varlabels(gender_committee Female_share) posthead("") prefoot("") postfoot("") /*
*/ varwidth(20) modelwidth(7) delimiter("") style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) 


*****************************************************************************************************************************
*****Table 8: Evaluation or Performance? Written vs. Oral Exams**************************************************************
*****************************************************************************************************************************

capture xi: xtreg ln_female_successful_candidates minority majority age_committee experience_committee ranking_committee /*
*/ ln_available_positions if written==0, fe i(corps_year) cluster(corps_year)
est store a
capture xi: xtreg ln_female_successful_candidates minority majority age_committee experience_committee ranking_committee /*
*/ ln_available_positions if written==1, fe i(corps_year) cluster(corps_year)
est store b
capture xi: xtreg ln_male_successful_candidates minority majority age_committee experience_committee ranking_committee /*
*/ ln_available_positions if written==0, fe i(corps_year) cluster(corps_year)
est store c
capture xi: xtreg ln_male_successful_candidates minority majority age_committee experience_committee ranking_committee /*
*/ ln_available_positions if written==1, fe i(corps_year) cluster(corps_year)
est store d
capture xi: xtreg ln_share_successful_female minority majority age_committee experience_committee ranking_committee /*
*/ ln_available_positions if written==0, fe i(corps_year) cluster(corps_year)
est store e
capture xi: xtreg ln_share_successful_female minority majority age_committee experience_committee ranking_committee /*
*/ ln_available_positions if written==1, fe i(corps_year) cluster(corps_year)
est store f
capture xi: xtreg ln_successful_candidates minority majority age_committee experience_committee ranking_committee /*
*/ ln_available_positions if written==0, fe i(corps_year) cluster(corps_year)
est store g
capture xi: xtreg ln_successful_candidates minority majority age_committee experience_committee ranking_committee /*
*/ ln_available_positions if written==1, fe i(corps_year) cluster(corps_year)
est store h

estout a b c d e f g h,/*
*/ drop(_cons) /*
*/ cells(b(star fmt(%9.2f)) se(par fmt(%9.2f))) stats(N, fmt(%9.0f)/*
*/ labels(N)) legend label collabels(, none) /*
*/ varlabels(gender_committee Female_share) posthead("") prefoot("") postfoot("") /*
*/ varwidth(20) modelwidth(7) delimiter("") style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) 


*****************************************************************************************************************************
*****Table 9: Who is Discriminated?******************************************************************************************
*****************************************************************************************************************************

**COLUMNS (1)-(4)
clear
use "committees.dta"
capture xi: xtreg ln_female_successful_candidates minority majority age_committee experience_committee ranking_committee /*
*/ ln_available_positions if binding==0, fe i(corps_year) cluster(corps_year)
est store a
capture xi: xtreg ln_male_successful_candidates minority majority age_committee experience_committee ranking_committee /*
*/ ln_available_positions if binding==0, fe i(corps_year) cluster(corps_year)
est store b
capture xi: xtreg ln_share_successful_female minority majority age_committee experience_committee ranking_committee /*
*/ ln_available_positions if binding==0, fe i(corps_year) cluster(corps_year)
est store c
capture xi: xtreg ln_successful_candidates minority majority age_committee experience_committee ranking_committee /*
*/ ln_available_positions if binding==0, fe i(corps_year) cluster(corps_year)
est store d

estout a b c d,/*
*/ drop(ln_available_positions _cons) /*
*/ cells(b(star fmt(%9.2f)) se(par fmt(%9.2f))) stats(N, fmt(%9.0f)/*
*/ labels(N)) legend label collabels(, none) /*
*/ varlabels(gender_committee Female_share) posthead("") prefoot("") postfoot("") /*
*/ varwidth(20) modelwidth(7) delimiter("") style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) 

**COLUMN (5)
clear
use "successful candidates.dta"
keep if male==0
bys year corps committee: egen passed_exam=count(finalgrade)
gsort year corps committee -finalgrade
gen order=1
replace order=order[_n-1]+1 if fixed==fixed[_n-1] & committee==committee[_n-1]
bys year corps: egen minimum_number_passed_exam=min(passed_exam)

capture xi: areg normalized_grade minority majority age_committee experience_committee ranking_committee /*
*/ if order<=minimum_number_passed_exam, absorb(corps_year) cluster(corps_year_committee)

est store e

estout e ,/*
*/ drop(_cons) /*
*/ cells(b(star fmt(%9.2f)) se(par fmt(%9.2f))) stats(N, fmt(%9.0f)/*
*/ labels(N)) legend label collabels(, none) /*
*/ varlabels(gender_committee Female_share) posthead("") prefoot("") postfoot("") /*
*/ varwidth(20) modelwidth(7) delimiter("") style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) 

**COLUMN (6)

**MALE GRADES**
clear
use "successful candidates.dta"
keep if male==1
bys year corps committee: egen passed_exam=count(finalgrade)
gsort year corps committee -finalgrade
gen order=1
replace order=order[_n-1]+1 if fixed==fixed[_n-1] & committee==committee[_n-1]
bys year corps: egen minimum_number_passed_exam=min(passed_exam)

capture xi: areg normalized_grade minority majority age_committee experience_committee ranking_committee/*
*/ if order<=minimum_number_passed_exam, absorb(corps_year) cluster(corps_year_committee)


est store f
estout f,/*
*/ drop(_cons) /*
*/ cells(b(star fmt(%9.2f)) se(par fmt(%9.2f))) stats(N, fmt(%9.0f)/*
*/ labels(N)) legend label collabels(, none) /*
*/ varlabels(gender_committee Female_share) posthead("") prefoot("") postfoot("") /*
*/ varwidth(20) modelwidth(7) delimiter("") style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) 

*****************************************************************************************************************************
*****Table 10: Probability of Success by Gender and Gender Composition of Committee, 2003-2007*******************************
*****************************************************************************************************************************

use "candidates.dta", clear
gen depvar1=finalgrade
gen depvar2=finalgrade
replace depvar1=. if finalgrade==0
replace depvar2=25 if finalgrade==0

capture xi: intreg depvar1 depvar2  i.female*i.female_committee_members multiple_choice_grade i.experience_candidate i.corps_year/*
*/ if passed1==1, vce(cluster corps_year_committee)

est store a

estout a, /*
*/ drop(_cons _Icorps_yea* ) /*
*/ order(_Ifemale_1 _Ifemale_co_2 _IfemXfem_1_2 _Ifemale_co_3 _IfemXfem_1_3 _Ifemale_co_4 _IfemXfem_1_4 _Ifemale_co_5 _IfemXfem_1_5) /*
*/ cells(b(star fmt(%9.2f)) se(par fmt(%9.2f))) stats(r2_p N,  fmt(%9.3f %9.0f)/*
*/ labels("Pseudo R-sq" N)) legend label collabels(, none) /*
*/ varlabels(gender_committee Female_share) posthead("") prefoot("") postfoot("") /*
*/ varwidth(40) modelwidth(7) delimiter("") style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) 


*COLUMN 2
capture xi: probit win i.female*i.female_committee_members multiple_choice_grade i.experience_candidate i.corps_year /*
*/ if passed1==1, vce(cluster corps_year_committee)
capture mfx compute
est store b

estout b,/*
*/ drop(_cons _Icorps_yea* ) /*
*/ order(_Ifemale_1 _Ifemale_co_2 _IfemXfem_1_2 _Ifemale_co_3 _IfemXfem_1_3 _Ifemale_co_4 _IfemXfem_1_4 _Ifemale_co_5 _IfemXfem_1_5) /*
*/ cells(Xmfx_dydx(star fmt(%9.2f)) Xmfx_se_dydx(par fmt(%9.2f))) stats(r2_p N,  fmt(%9.3f %9.0f)/*
*/ labels("Adjusted R-sq" N)) legend label collabels(, none) /*
*/ varlabels(gender_committee Female_share) posthead("") prefoot("") postfoot("") /*
*/ varwidth(30) modelwidth(7) delimiter("") style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) 

